#include <DHT12.h>
#include <LiquidCrystal_I2C.h>

#define CELSIUS (char)0

/*
  ..OO.
  .O..O
  .O..O
  ..OO.
  .....
  .....
  .....
*/
uint8_t celsius[8]  = {
  0b00110,
  0b01001,
  0b01001,
  0b00110,
  0b00000,
  0b00000,
  0b00000
};

DHT12 dht12;

LiquidCrystal_I2C lcd(0x27, 16, 2);

void setup() {
  dht12.begin();
  lcd.init();
  lcd.backlight();
  lcd.createChar(CELSIUS, celsius);
}

void loop() {
  /*
     READ DATA
  */
  int status = dht12.read();
  lcd.clear();
  switch (status)   {
    case DHT12_OK:
      /*
        DISPLAY DATA.
      */
      lcd.setCursor(0, 0);
      lcd.print(F("T = "));
      lcd.print(dht12.getTemperature());
      lcd.print(CELSIUS);
      lcd.print(F("C"));

      lcd.setCursor(0, 1);
      lcd.print(F("H = "));
      lcd.print(dht12.getHumidity());
      lcd.print(F(" %"));

      break;
    case DHT12_ERROR_CHECKSUM:
      lcd.setCursor(0, 0);
      lcd.print(F("Checksum error"));
      break;
    case DHT12_ERROR_CONNECT:
      lcd.setCursor(0, 0);
      lcd.print(F("Connect error"));
      break;
    case DHT12_MISSING_BYTES:
      lcd.setCursor(0, 0);
      lcd.print(F("Missing bytes"));
      break;
    default:
      lcd.setCursor(0, 0);
      lcd.print(F("Unknown error"));
      break;
  }
  delay(2000);
}